@@ -22,7 +22,7 @@ use base qw/Net::DRI::DRD/;
 
 use Net::DRI::Util;
 
-our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -93,6 +93,11 @@ sub transport_protocol_compatible
  return;
 }
 
+sub transport_protocol_default
+{
+ return ('Net::DRI::Transport::Socket','Net::DRI::Protocol::EPP::Extensions::PL');
+}
+
 ######################################################################################
 
 sub verify_name_domain
