@@ -1,6 +1,6 @@
 ## Domain Registry Interface, EPP Host commands (RFC3732)
 ##
-## Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005,2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -27,7 +27,7 @@ use Net::DRI::Protocol::EPP::Core::Status;
 
 use DateTime::Format::ISO8601;
 
-our $VERSION=do { my @r=(q$Revision: 1.3 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.4 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -57,7 +57,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005,2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -127,19 +127,19 @@ sub check_parse
  return unless $chkdata;
  foreach my $cd ($chkdata->getElementsByTagNameNS($mes->ns('host'),'cd'))
  {
-  my $c=$cd->firstChild;
+  my $c=$cd->getFirstChild();
   my $host;
   while($c)
   {
-   my $n=$c->nodeName();
-   if ($n eq 'host:name')
+   my $n=$c->localname() || $c->nodeName();
+   if ($n eq 'name')
    {
-    $host=$c->firstChild->getData();
+    $host=$c->getFirstChild()->getData();
     $rinfo->{host}->{$host}->{exist}=1-Net::DRI::Util::xml_parse_boolean($c->getAttribute('avail'));
    }
-   if ($n eq 'host:reason')
+   if ($n eq 'reason')
    {
-    $rinfo->{host}->{$host}->{exist_reason}=$c->firstChild->getData();
+    $rinfo->{host}->{$host}->{exist_reason}=$c->getFirstChild()->getData();
    }
    $c=$c->getNextSibling();
   }
@@ -166,26 +166,26 @@ sub info_parse
  $rinfo->{host}->{$oname}->{exist}=1;
  my (@s,@ip4,@ip6);
 
- my $c=$infdata->firstChild();
+ my $c=$infdata->getFirstChild();
  while ($c) ## host:name is not used
  {
-  my $name=$c->nodeName();
+  my $name=$c->localname() || $c->nodeName();
   next unless $name;
-  if ($name=~m/^host:(clID|crID|upID)$/)
+  if ($name=~m/^(clID|crID|upID)$/)
   {
-   $rinfo->{host}->{$oname}->{$1}=$c->firstChild->getData();
-  } elsif ($name=~m/^host:(crDate|upDate|trDate)$/)
+   $rinfo->{host}->{$oname}->{$1}=$c->getFirstChild()->getData();
+  } elsif ($name=~m/^(crDate|upDate|trDate)$/)
   {
-   $rinfo->{host}->{$oname}->{$1}=DateTime::Format::ISO8601->new()->parse_datetime($c->firstChild->getData());
-  } elsif ($name eq 'host:roid')
+   $rinfo->{host}->{$oname}->{$1}=DateTime::Format::ISO8601->new()->parse_datetime($c->getFirstChild()->getData());
+  } elsif ($name eq 'roid')
   {
-   $rinfo->{host}->{$oname}->{roid}=$c->firstChild->getData();
-  } elsif ($name eq 'host:status')
+   $rinfo->{host}->{$oname}->{roid}=$c->getFirstChild()->getData();
+  } elsif ($name eq 'status')
   {
    push @s,Net::DRI::Protocol::EPP::parse_status($c);
-  } elsif ($name eq 'host:addr')
+  } elsif ($name eq 'addr')
   {
-   my $ip=$c->firstChild->getData();
+   my $ip=$c->getFirstChild()->getData();
    my $ipv=$c->getAttribute('ip');
    push @ip4,$ip if ($ipv eq 'v4');
    push @ip6,$ip if ($ipv eq 'v6');
@@ -218,13 +218,13 @@ sub create_parse
  return unless $infdata;
 
  $rinfo->{host}->{$oname}->{exist}=1;
- my $c=$infdata->firstChild();
+ my $c=$infdata->getFirstChild();
  while ($c) ## host:name is not used
  {
-  my $name=$c->nodeName();
-  if ($name=~m/^host:(crDate)$/)
+  my $name=$c->localname() || $c->nodeName();
+  if ($name=~m/^(crDate)$/)
   {
-   $rinfo->{host}->{$oname}->{$1}=DateTime::Format::ISO8601->new()->parse_datetime($c->firstChild->getData());
+   $rinfo->{host}->{$oname}->{$1}=DateTime::Format::ISO8601->new()->parse_datetime($c->getFirstChild()->getData());
   }
   $c=$c->getNextSibling();
  }
