@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .AERO Contact EPP extension commands
 ##
-## Copyright (c) 2006-2008,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,16 +10,19 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::AERO::Contact;
 
 use strict;
-use warnings;
 
-use Net::DRI::Util;
 use DateTime::Format::ISO8601;
 
+our $VERSION=do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -48,7 +51,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2008,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -80,31 +83,31 @@ sub info_parse
  my $mes=$po->message();
  return unless $mes->is_success();
 
- my $infdata=$mes->get_extension('aero','infData');
+ my $infdata=$mes->get_content('infData',$mes->ns('aero'),1);
  return unless $infdata;
 
- my $c=$infdata->getChildrenByTagNameNS($mes->ns('aero'),'ensInfo');
+ my $c=$infdata->getElementsByTagNameNS($mes->ns('aero'),'ensInfo');
  return unless ($c && $c->size()==1);
  $c=$c->shift()->getFirstChild();
 
  my %ens;
  while($c)
  {
-  next unless ($c->nodeType() == 1); ## only for element nodes
   my $name=$c->localname() || $c->nodeName();
   next unless $name;
 
   if (my ($tag)=($name=~m/^(\S+)$/))
   {
-   $ens{Net::DRI::Util::remcam($tag)}=$c->getFirstChild()->getData();
+   $tag=~s/([A-Z])/_$1/g;
+   $ens{lc($tag)}=$c->getFirstChild()->getData();
   }
 
- } continue { $c=$c->getNextSibling(); }
+  $c=$c->getNextSibling();
+ }
 
  $ens{last_checked_date}=DateTime::Format::ISO8601->new()->parse_datetime($ens{last_checked_date}) if exists($ens{last_checked_date});
 
  $rinfo->{contact}->{$oname}->{self}->ens(\%ens);
- return;
 }
 
 ####################################################################################################
