@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .AERO Domain EPP extension commands
 ##
-## Copyright (c) 2006-2008,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,15 +10,19 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::AERO::Domain;
 
 use strict;
-use warnings;
 
 use Net::DRI::Exception;
 
+our $VERSION=do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -47,7 +51,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2008,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -74,9 +78,18 @@ sub register_commands
 
 ####################################################################################################
 
+sub build_command_extension
+{
+ my ($mes,$epp,$tag)=@_;
+ 
+ my @ns=@{$mes->ns()->{'aero'}};
+ return $mes->command_extension_register($tag,sprintf('xmlns:aero="%s" xsi:schemaLocation="%s %s"',$ns[0],$ns[0],$ns[1]));
+}
+
 sub create
 {
  my ($epp,$domain,$rd)=@_;
+ my $mes=$epp->message();
 
  Net::DRI::Exception::usererr_insufficient_parameters('ens attribute is mandatory, as ref hash with keys auth_id and auth_key') 
          unless (exists($rd->{ens}) && (ref($rd->{ens}) eq 'HASH') && exists($rd->{ens}->{auth_id}) && $rd->{ens}->{auth_id} && exists($rd->{ens}->{auth_key}) && $rd->{ens}->{auth_key});
@@ -85,8 +98,8 @@ sub create
  push @n,['aero:ensAuthID',$rd->{ens}->{auth_id}];
  push @n,['aero:ensAuthKey',$rd->{ens}->{auth_key}];
 
- $epp->message()->command_extension('aero', ['create', @n]);
- return;
+ my $eid=build_command_extension($mes,$epp,'aero:create');
+ $mes->command_extension($eid,\@n);
 }
 
 sub info_parse
@@ -95,14 +108,13 @@ sub info_parse
  my $mes=$po->message();
  return unless $mes->is_success();
 
- my $infdata=$mes->get_extension('aero','infData');
+ my $infdata=$mes->get_content('infData',$mes->ns('aero'),1);
  return unless $infdata;
 
  my %ens;
  my $c=$infdata->getFirstChild();
  while($c)
  {
-  next unless ($c->nodeType() == 1); ## only for element nodes
   my $name=$c->localname() || $c->nodeName();
   next unless $name;
 
@@ -111,10 +123,10 @@ sub info_parse
    $ens{auth_id}=$c->getFirstChild()->getData();
   }
 
- } continue { $c=$c->getNextSibling(); }
+  $c=$c->getNextSibling();
+ }
 
  $rinfo->{domain}->{$oname}->{ens}=\%ens;
- return;
 }
 
 ####################################################################################################
