@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .CAT Defensive Registration EPP extension commands
 ##
-## Copyright (c) 2006-2010,2013-2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,22 +10,28 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::CAT::DefensiveRegistration;
 
 use strict;
-use warnings;
 
 use Net::DRI::Util;
 use Net::DRI::Exception;
-use Net::DRI::Protocol::EPP::Util;
+use Net::DRI::Protocol::EPP::Core::Domain;
+use Net::DRI::Protocol::EPP::Core::Status;
+use DateTime::Format::ISO8601;
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
 =head1 NAME
 
-Net::DRI::Protocol::EPP::Extensions::CAT::DefensiveRegistration - .CAT EPP Defensive Registration extension commands for Net::DRI
+Net::DRI::Protocol::EPP::Extensions::CAT::DefensiveRegistration - EPP .CAT Defensive Registration extension commands for Net::DRI
 
 =head1 DESCRIPTION
 
@@ -49,7 +55,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2010,2013-2016,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -79,6 +85,17 @@ sub register_commands
  return { 'defreg' => \%tmp1 };
 }
 
+sub capabilities_add
+{
+ return { 'defreg_update' => { 'status' => ['add','del'], 'contact' => ['add','del'], 'registrant' => ['set'], 'auth' => ['set'], 'maintainer' => ['set'], 'trademark' => ['set'] } };
+}
+
+sub ns
+{
+ my $mes=shift;
+ return wantarray()? @{$mes->ns()->{'puntcat_defreg'}} : $mes->ns('puntcat_defreg');
+}
+
 sub build_command
 {
  my ($epp,$command,$id)=@_;
@@ -87,13 +104,14 @@ sub build_command
  my @id;
  foreach my $n ( grep { defined } (ref($id) eq 'ARRAY')? @$id : ($id))
  {
-  Net::DRI::Exception->die(1,'protocol/EPP',10,'Invalid defensive registration id '.$n) unless ($n && !ref($n) && Net::DRI::Util::xml_is_token($n,3,16));
+  Net::DRI::Exception->die(1,'protocol/EPP',10,'Invalid defensive registration id '.$n) unless ($n && Net::DRI::Util::xml_is_token($n,3,16));
   push @id,$n;
  }
 
  Net::DRI::Exception->die(1,'protocol/EPP',2,'Defensive registration id needed') unless @id;
 
- $mes->command([$command,'defreg:'.$command, $mes->nsattrs('defreg')]);
+ my @ns=ns($mes);
+ $mes->command([$command,'defreg:'.$command,sprintf('xmlns:defreg="%s" xsi:schemaLocation="%s %s"',$ns[0],$ns[0],$ns[1])]);
  return map { ['defreg:id',$_] } @id;
 }
 
@@ -109,7 +127,7 @@ sub build_contact
 {
  my ($d,$type)=@_;
  Net::DRI::Exception::usererr_insufficient_parameters($type.' contact is mandatory') unless (defined($d) && $d);
- $d=$d->srid() if Net::DRI::Util::isa_contact($d,'Net::DRI::Data::Contact::CAT');
+ $d=$d->srid() if UNIVERSAL::isa($d,'Net::DRI::Data::Contact');
  Net::DRI::Exception->die(1,'protocol/EPP',10,"Invalid $type contact id: $d") unless Net::DRI::Util::xml_is_token($d,3,16);
  return ($type eq 'registrant')? ['defreg:registrant',$d] : ['defreg:contact',$d,{type => $type}];
 }
@@ -146,7 +164,7 @@ sub build_maintainer
 sub build_trademark
 {
  my ($d)=@_;
- Net::DRI::Exception::usererr_insufficient_parameters('trademark is mandatory') unless (defined $d && ref $d eq 'HASH' && keys %$d);
+ Net::DRI::Exception::usererr_insufficient_parameters('trademark is mandatory') unless (defined($d) && (ref($d) eq 'HASH') && keys(%$d));
  my %t=%$d;
  my @n;
  if (exists($t{name}))
@@ -174,7 +192,7 @@ sub build_trademark
 
 sub build_period
 {
- my $p=Net::DRI::Protocol::EPP::Util::build_period(shift);
+ my $p=Net::DRI::Protocol::EPP::Core::Domain::build_period(shift);
  $p->[0]='defreg:period';
  return $p;
 }
@@ -184,10 +202,10 @@ sub build_period
 
 sub check
 {
- my ($epp,@id)=@_;
+ my $epp=shift;
+ my @id=@_;
  my @d=build_command($epp,'check',\@id);
  $epp->message->command_body(\@d);
- return;
 }
 
 sub check_parse
@@ -196,37 +214,36 @@ sub check_parse
  my $mes=$po->message();
  return unless $mes->is_success();
 
- my $chkdata=$mes->get_response('defreg', 'chkData');
- return unless defined $chkdata;
+ my $ns=ns($mes);
+ my $chkdata=$mes->get_content('chkData',$ns);
+ return unless $chkdata;
 
- my $ns=$mes->ns('defreg');
- foreach my $cd ($chkdata->getChildrenByTagNameNS($ns,'cd'))
+ foreach my $cd ($chkdata->getElementsByTagNameNS($ns,'cd'))
  {
+  my $c=$cd->getFirstChild();
   my $id;
-  foreach my $el (Net::DRI::Util::xml_list_children($cd))
+  while($c)
   {
-   my ($n,$c)=@$el;
-   if ($n eq 'id')
+   my $n=$c->nodeName();
+   if ($n eq 'defreg:id')
    {
-    $id=$c->textContent();
-    $rinfo->{defreg}->{$id}->{action}='check';
+    $id=$c->getFirstChild()->getData();
     $rinfo->{defreg}->{$id}->{exist}=1-Net::DRI::Util::xml_parse_boolean($c->getAttribute('avail'));
-   } elsif ($n eq 'reason')
+   } elsif ($n eq 'defreg:reason')
    {
-    $rinfo->{defreg}->{$id}->{exist_reason}=$c->textContent();
+    $rinfo->{defreg}->{$id}->{exist_reason}=$c->getFirstChild()->getData();
    }
+   $c=$c->getNextSibling();
   }
  }
- return;
 }
 
 sub info
 {
  my ($epp,$id,$rd)=@_;
  my @d=build_command($epp,'info',$id);
- push @d,build_authinfo($rd->{auth}) if Net::DRI::Util::has_auth($rd);
+ push @d,build_authinfo($rd->{auth}) if (defined($rd) && (ref($rd) eq 'HASH') && exists($rd->{auth}) && (ref($rd->{auth}) eq 'HASH'));
  $epp->message->command_body(\@d);
- return;
 }
 
 sub info_parse
@@ -235,79 +252,77 @@ sub info_parse
  my $mes=$po->message();
  return unless $mes->is_success();
 
- my $infdata=$mes->get_response('defreg', 'infData');
- return unless defined $infdata;
+ my $ns=ns($mes);
+ my $infdata=$mes->get_content('infData',$ns);
+ return unless $infdata;
 
- my $ns=$mes->ns('defreg');
  my (@s,%t);
- my $cs=$po->create_local_object('contactset');
- my %ccache;
- foreach my $el (Net::DRI::Util::xml_list_children($infdata))
+ my $cs=Net::DRI::Data::ContactSet->new();
+ my $cf=$po->factories->{contact};
+ my $c=$infdata->getFirstChild();
+ while ($c)
  {
-  my ($name,$c)=@$el;
-  if ($name eq 'id')
+  my $name=$c->nodeName();
+  next unless $name;
+
+  if ($name eq 'defreg:roid')
   {
-   $oname=$c->textContent();
-   $rinfo->{defreg}->{$oname}->{id}=$oname;
-  } elsif ($name eq 'roid')
+   $rinfo->{defreg}->{$oname}->{roid}=$c->getFirstChild()->getData();
+  } elsif ($name eq 'defreg:pattern')
   {
-   $rinfo->{defreg}->{$oname}->{roid}=$c->textContent();
-  } elsif ($name eq 'pattern')
+   $rinfo->{defreg}->{$oname}->{pattern}=$c->getFirstChild()->getData();
+  } elsif ($name eq 'defreg:status')
   {
-   $rinfo->{defreg}->{$oname}->{pattern}=$c->textContent();
-  } elsif ($name eq 'status')
+   push @s,Net::DRI::Protocol::EPP::parse_status($c);
+  } elsif ($name eq 'defreg:registrant')
   {
-   push @s,Net::DRI::Protocol::EPP::Util::parse_node_status($c);
-  } elsif ($name eq 'registrant')
+   $cs->set($cf->()->srid($c->getFirstChild()->getData()),'registrant');
+  } elsif ($name eq 'defreg:contact')
   {
-   my $id=$c->textContent();
-   $ccache{$id}=$po->create_local_object('contact')->srid($id) unless exists $ccache{$id};
-   $cs->set($ccache{$id},'registrant');
-  } elsif ($name eq 'contact')
+   $cs->add($cf->()->srid($c->getFirstChild()->getData()),$c->getAttribute('type'));
+  } elsif ($name=~m/^defreg:(clID|crID|upID)$/)
   {
-   my $id=$c->textContent();
-   $ccache{$id}=$po->create_local_object('contact')->srid($id) unless exists $ccache{$id};
-   $cs->add($ccache{$id},$c->getAttribute('type'));
-  } elsif ($name=~m/^(clID|crID|upID)$/)
+   $rinfo->{defreg}->{$oname}->{$1}=$c->getFirstChild()->getData();
+  } elsif ($name=~m/^defreg:(crDate|upDate|exDate)$/)
   {
-   $rinfo->{defreg}->{$oname}->{$1}=$c->textContent();
-  } elsif ($name=~m/^(crDate|upDate|exDate)$/)
+   $rinfo->{defreg}->{$oname}->{$1}=DateTime::Format::ISO8601->new()->parse_datetime($c->getFirstChild()->getData());
+  } elsif ($name eq 'defreg:authInfo')
   {
-   $rinfo->{defreg}->{$oname}->{$1}=$po->parse_iso8601($c->textContent());
-  } elsif ($name eq 'authInfo')
+   $rinfo->{defreg}->{$oname}->{auth}={pw=>($c->getElementsByTagNameNS($ns,'pw'))[0]->getFirstChild()->getData()};
+  } elsif ($name eq 'defreg:maintainer')
   {
-   $rinfo->{defreg}->{$oname}->{auth}={ pw => Net::DRI::Util::xml_child_content($c,$ns,'pw') };
-  } elsif ($name eq 'maintainer')
+   $rinfo->{defreg}->{$oname}->{maintainer}=$c->getFirstChild()->getData();
+  } elsif ($name eq 'defreg:trademark')
   {
-   $rinfo->{defreg}->{$oname}->{maintainer}=$c->textContent();
-  } elsif ($name eq 'trademark')
-  {
-   foreach my $sel (Net::DRI::Util::xml_list_children($c))
+   my $cc=$c->getFirstChild();
+   while($cc)
    {
-    my ($name2,$cc)=@$sel;
-    if ($name2 eq 'name')
+    my $name2=$cc->nodeName();
+    next unless $name2;
+    if ($name2 eq 'defreg:name')
     {
-     $t{name}=$cc->textContent();
-    } elsif ($name2 eq 'issueDate')
+     $t{name}=$cc->getFirstChild()->getData();
+    } elsif ($name2 eq 'defreg:issueDate')
     {
-     $t{issue_date}=$po->parse_iso8601($cc->textContent());
-    } elsif ($name2 eq 'country')
+     $t{issue_date}=DateTime::Format::ISO8601->new()->parse_datetime($cc->getFirstChild()->getData());
+    } elsif ($name2 eq 'defreg:country')
     {
-     $t{country}=$cc->textContent();
-    } elsif ($name2 eq 'number')
+     $t{country}=$cc->getFirstChild()->getData();
+    } elsif ($name2 eq 'defreg:number')
     {
-     $t{number}=$cc->textContent();
+     $t{number}=$cc->getFirstChild()->getData();
     }
+    $cc=$cc->getNextSibling();
    }
   }
+
+  $c=$c->getNextSibling();
  }
 
- $rinfo->{defreg}->{$oname}->{action}='info';
  $rinfo->{defreg}->{$oname}->{exist}=1;
  $rinfo->{defreg}->{$oname}->{contact}=$cs;
- $rinfo->{defreg}->{$oname}->{status}=$po->create_local_object('status')->add(@s);
+ $rinfo->{defreg}->{$oname}->{status}=Net::DRI::Protocol::EPP::Core::Status->new(\@s);
  $rinfo->{defreg}->{$oname}->{trademark}=\%t;
- return;
 }
 
 ####################################################################################################
@@ -318,7 +333,7 @@ sub create
  my ($epp,$id,$ri)=@_;
  my @d=build_command($epp,'create',$id);
 
- Net::DRI::Exception::usererr_invalid_parameters('A ref hash with all info must be provided alongside the id') unless (defined $ri && ref $ri eq 'HASH' && keys %$ri);
+ Net::DRI::Exception::usererr_invalid_parameters('A ref hash with all info must be provided alongside the id') unless (defined($ri) && (ref($ri) eq 'HASH') && keys(%$ri));
 
  ## Period, OPTIONAL
  if (exists($ri->{duration}))
@@ -330,7 +345,7 @@ sub create
 
  Net::DRI::Exception::usererr_invalid_parameters('pattern must be an XML token between 1 and 63 chars long') unless (exists($ri->{pattern}) && $ri->{pattern} && Net::DRI::Util::xml_is_token($ri->{pattern},1,63));
  push @d,['defreg:pattern',$ri->{pattern}];
- Net::DRI::Exception::usererr_invalid_parameters('a valid contactset object must be given in contact attribute') unless Net::DRI::Util::has_contact($ri);
+ Net::DRI::Exception::usererr_invalid_parameters('a valid contactset object must be given in contact attribute') unless (exists($ri->{contact}) && UNIVERSAL::isa($ri->{contact},'Net::DRI::Data::ContactSet'));
  my $cs=$ri->{contact};
  push @d,build_contact($cs->get('registrant'),'registrant');
  push @d,build_contact($cs->get('billing'),'billing');
@@ -341,24 +356,20 @@ sub create
  Net::DRI::Exception::usererr_insufficient_parameters('trademark must be a ref hash with 4 keys: name, issue_date, country, number') unless (@$tmp==5);
  push @d,$tmp;
  $epp->message->command_body(\@d);
- return;
 }
 
-sub delete ## no critic (Subroutines::ProhibitBuiltinHomonyms)
+sub delete
 {
  my ($epp,$id)=@_;
  my @d=build_command($epp,'delete',$id);
  $epp->message->command_body(\@d);
- return;
 }
 
 sub renew
 {
- my ($epp,$id,$rd)=@_;
- my $period=(defined($rd) && (ref($rd) eq 'HASH') && exists($rd->{duration}))? $rd->{duration} : undef;
- my $curexp=(defined($rd) && (ref($rd) eq 'HASH') && exists($rd->{current_expiration}))? $rd->{current_expiration} : undef;
+ my ($epp,$id,$period,$curexp)=@_;
  Net::DRI::Exception::usererr_insufficient_parameters('current expiration year') unless defined($curexp);
- $curexp=$curexp->set_time_zone('UTC')->strftime('%Y-%m-%d') if (ref $curexp && Net::DRI::Util::is_class($curexp,'DateTime'));
+ $curexp=$curexp->set_time_zone('UTC')->strftime('%Y-%m-%d') if (ref($curexp) && UNIVERSAL::isa($curexp,'DateTime'));
  Net::DRI::Exception::usererr_invalid_parameters('current expiration year must be YYYY-MM-DD') unless $curexp=~m/^\d{4}-\d{2}-\d{2}$/;
 
  my @d=build_command($epp,'renew',$id);
@@ -370,7 +381,6 @@ sub renew
  }
 
  $epp->message->command_body(\@d);
- return;
 }
 
 sub update
@@ -378,7 +388,7 @@ sub update
  my ($epp,$id,$todo)=@_;
  my $mes=$epp->message();
 
- Net::DRI::Exception::usererr_invalid_parameters($todo.' must be a Net::DRI::Data::Changes object') unless Net::DRI::Util::isa_changes($todo);
+ Net::DRI::Exception::usererr_invalid_parameters($todo." must be a Net::DRI::Data::Changes object") unless ($todo && UNIVERSAL::isa($todo,'Net::DRI::Data::Changes'));
 
   if ((grep { ! /^(?:add|del)$/ } $todo->types('status')) ||
      (grep { ! /^(?:add|del)$/ } $todo->types('contact')) ||
@@ -410,7 +420,7 @@ sub update
  my (@chg,$chg);
 
  $chg=$todo->set('registrant');
- push @chg,['defreg:registrant',$chg->srid()] if Net::DRI::Util::isa_contact($chg,'Net::DRI::Data::Contact::CAT');
+ push @chg,['defreg:registrant',$chg->srid()] if ($chg && ref($chg) && UNIVERSAL::can($chg,'srid'));
  $chg=$todo->set('auth');
  push @chg,build_authinfo($chg) if ($chg && ref($chg));
  $chg=$todo->set('maintainer');
@@ -420,7 +430,6 @@ sub update
 
  push @d,['defreg:chg',@chg] if @chg;
  $mes->command_body(\@d);
- return;
 }
 
 ####################################################################################################
