@@ -1,6 +1,6 @@
 ## Domain Registry Interface, VeriSign EPP extensions
 ##
-## Copyright (c) 2006,2008-2014 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,15 +10,18 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::VeriSign;
 
 use strict;
-use warnings;
 
 use base qw/Net::DRI::Protocol::EPP/;
-use Net::DRI::Data::Contact::JOBS;
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -30,8 +33,6 @@ Net::DRI::Protocol::EPP::Extensions::VeriSign - VeriSign EPP extensions for Net:
 
 Please see the README file for details.
 
-Note that the PremiumDomain extension is not loaded by default.
-
 =head1 SUPPORT
 
 For now, support questions should be sent to:
@@ -50,7 +51,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2008-2014 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -63,25 +64,30 @@ See the LICENSE file that comes with this distribution for more details.
 =cut
 
 ####################################################################################################
-
-sub setup
+sub new
 {
- my ($self,$rp)=@_;
- $self->default_parameters()->{subproductid}=$rp->{default_product} || '_auto_';
- $self->default_parameters()->{whois_info}=0;
- $self->factories('contact',sub { return Net::DRI::Data::Contact::JOBS->new(@_); }) if $self->has_module('Net::DRI::Protocol::EPP::Extensions::VeriSign::JobsContact');
- return;
-}
+ my $h=shift;
+ my $c=ref($h) || $h;
 
-## List of VeriSign extensions: http://www.verisigninc.com/en_US/channel-resources/domain-registry-products/epp-sdks/index.xhtml?loc=en_US
-sub default_extensions
-{
- my ($self,$rp)=@_;
- my @c=qw/VeriSign::Sync VeriSign::PollLowBalance VeriSign::PollRGP VeriSign::IDNLanguage VeriSign::WhoWas VeriSign::Suggestion VeriSign::ClientAttributes VeriSign::TwoFactorAuth VeriSign::ZoneManagement VeriSign::Balance GracePeriod SecDNS/;
- push @c,'VeriSign::WhoisInfo'   if !exists $rp->{default_product} || (defined $rp->{default_product} && $rp->{default_product} ne 'dotCC' && $rp->{default_product} ne 'dotTV' );
- push @c,'VeriSign::JobsContact' if exists $rp->{default_product} && defined $rp->{default_product} && $rp->{default_product} eq 'dotJOBS';
- push @c,'VeriSign::NameStore'; ## this must come last
- return @c;
+ my ($drd,$version,$extrah,$defproduct)=@_;
+ my %e=map { $_ => 1 } (defined($extrah)? (ref($extrah)? @$extrah : ($extrah)) : ());
+
+ $e{'Net::DRI::Protocol::EPP::Extensions::VeriSign::NameStore'}=1;
+ $e{'Net::DRI::Protocol::EPP::Extensions::VeriSign::Sync'}=1;
+ ## We do no load automatically IDNLanguage & WhoisInfo as we do not know if they are mandatory
+ ## NameStore seems mandatory, and Sync is just another operation, hence optional in all cases
+ if (exists($e{':full'})) ## useful shortcut, modeled after Perl itself
+ {
+  delete($e{':full'});
+  $e{'Net::DRI::Protocol::EPP::Extensions::VeriSign::IDNLanguage'}=1;
+  $e{'Net::DRI::Protocol::EPP::Extensions::VeriSign::WhoisInfo'}=1;
+ }
+
+ my $self=$c->SUPER::new($drd,$version,[keys(%e)]); ## we are now officially a Net::DRI::Protocol::EPP object
+ $self->default_parameters()->{subproductid}=$defproduct || '_auto_';
+
+ bless($self,$c); ## rebless
+ return $self;
 }
 
 ####################################################################################################
