@@ -1,6 +1,6 @@
 ## Domain Registry Interface, EPP Whois Info (EPP-Whois-Info-Ext.pdf)
 ##
-## Copyright (c) 2006-2008,2012,2013,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,17 +10,20 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::VeriSign::WhoisInfo;
 
 use strict;
-use warnings;
-use feature 'state';
 
 use Net::DRI::Util;
 use Net::DRI::Exception;
 
+our $VERSION=do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -49,7 +52,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2008,2012,2013,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -61,22 +64,17 @@ See the LICENSE file that comes with this distribution for more details.
 
 =cut
 
+
 ####################################################################################################
 
 sub register_commands
 {
  my ($class,$version)=@_;
- state $cmds = { 'domain' => { 'info' => [ \&info, \&info_parse ] } };
+ my %tmp=(
+           info => [ \&info, \&info_parse ],
+         );
 
- return $cmds;
-}
-
-sub setup
-{
- my ($class,$po,$version)=@_;
- state $rns = { 'whoisInf' => 'http://www.verisign.com/epp/whoisInf-1.0'};
- $po->ns($rns);
- return;
+ return { 'domain' => \%tmp };
 }
 
 ####################################################################################################
@@ -84,28 +82,13 @@ sub setup
 sub info
 {
  my ($epp,$domain,$rd)=@_;
- my $defprod=$epp->default_parameters()->{subproductid};
- return if ($defprod eq '_auto_' && $domain=~m/\.(?:cc|tv)$/i);
+ my $mes=$epp->message();
 
- my $wi;
- if (Net::DRI::Util::has_key($rd,'whois_info'))
- {
-  $wi=$rd->{whois_info};
- } else
- {
-  my $def=$epp->default_parameters();
-  if (Net::DRI::Util::has_key($def,'whois_info'))
-  {
-   $wi=$def->{whois_info};
-  } else
-  {
-   Net::DRI::Exception::usererr_insufficient_parameters('Whois Info must be provided');
-  }
- }
- Net::DRI::Exception::usererr_invalid_parameters('Whois Info must be true/false/1/0') unless Net::DRI::Util::xml_is_boolean($wi);
-
- $epp->message()->command_extension('whoisInf', ['whoisInf', ['flag', $wi]]);
- return;
+ Net::DRI::Exception::usererr_insufficient_parameters('Whois Info must be provided') unless (defined($rd) && (ref($rd) && 'HASH') && exists($rd->{whois_info}));
+ Net::DRI::Exception::usererr_invalid_parameters('Whois Info must be true/false/1/0') unless Net::DRI::Util::xml_is_boolean($rd->{whois_info});
+ 
+ my $eid=$mes->command_extension_register('whoisInf:whoisInf','xmlns:whoisInf="http://www.verisign.com/epp/whoisInf-1.0" xsi:schemaLocation="http://www.verisign.com/epp/whoisInf-1.0 whoisInf-1.0.xsd"');
+ $mes->command_extension($eid,['whoisInf:flag',$rd->{whois_info}]);
 }
 
 sub info_parse
@@ -114,21 +97,32 @@ sub info_parse
  my $mes=$po->message();
  return unless $mes->is_success();
 
- my $infdata=$mes->get_extension('whoisInf','whoisInfData');
+ my $infdata=$mes->get_content('whoisInfData','http://www.verisign.com/epp/whoisInf-1.0',1);
  return unless $infdata;
 
  my %w;
- foreach my $el (Net::DRI::Util::xml_list_children($infdata))
+ my $c=$infdata->getFirstChild();
+ while ($c)
  {
-  my ($name,$c)=@$el;
-  if ($name=~m/^(?:registrar|whoisServer|url|irisServer)$/)
+  my $name=$c->localname() || $c->nodeName();
+  next unless $name;
+  if ($name eq 'registrar')
   {
-   $w{Net::DRI::Util::remcam($name)}=$c->textContent();
+   $w{registrar}=$c->getFirstChild()->getData();
+  } elsif ($name eq 'whoisServer')
+  {
+   $w{whois_server}=$c->getFirstChild()->getData();
+  } elsif ($name eq 'url')
+  {
+   $w{url}=$c->getFirstChild()->getData();
+  } elsif ($name eq 'irisServer')
+  {
+   $w{iris_server}=$c->getFirstChild()->getData();
   }
+  $c=$c->getNextSibling();
  }
 
  $rinfo->{domain}->{$oname}->{whois_info}=\%w;
- return;
 }
 
 ####################################################################################################
